@@ -1,22 +1,18 @@
+import subprocess
+
 import click
 
-from mobt.DotEnv.DotEnv import DotEnv
+from mobt import echo, prompt
 from mobt.GitCli.BranchName import BranchName
-from mobt.Gui.GuiService import GuiService
-from mobt.LastTeamMembers.LastTeamMembersService import LastTeamMembersService
-from mobt.LastTeamMembers.TeamMemberName import TeamMemberName
 from mobt.LastTeamMembers.TeamMembers import TeamMembers
-from mobt.MobApp.StartMobbing import StartMobbing
-from mobt.Timer.TimerService import TimerService
-from mobt.di import di
 
 
 def __ask_for_new_members_name() -> TeamMembers:
-    click.echo('Name of the team members. One per line. Minimum two.')
+    echo('Name of the team members. One per line. Minimum two.')
 
     members = []
     while True:
-        member = click.prompt('Name (empty to stop asking)', default='').strip()
+        member = prompt('Name (empty to stop asking)', default='').strip()
         if not member:
             break
         members.append(member)
@@ -46,11 +42,17 @@ def start(branch_name: BranchName, members: str = None, reset_members: bool = Fa
     If the BRANCH_NAME doesn't exist, it will create a new branch with that name and start a new mob session.
     """
 
+    from mobt.LastTeamMembers.LastTeamMembersService import LastTeamMembersService
+    from mobt.LastTeamMembers.TeamMemberName import TeamMemberName
+    from mobt.MobApp.StartMobbing import StartMobbing
+    from mobt.Gui.GuiService import GuiService
+    from mobt.Timer.TimerService import TimerService
+    from mobt.di import di
     last_team_members_service = di.get(LastTeamMembersService)
     if members:
         # Members were passed as a comma separated list.
         # We need to convert it to a list of TeamMemberName
-        members = [TeamMemberName(n.strip()) for n in members.split(',') if n and n.strip()]
+        members = TeamMembers([TeamMemberName(n.strip()) for n in members.split(',') if n and n.strip()])
 
     if members is None:
         # Members were not passed as a parameter, or it's an empty list. Load the last team members used.
@@ -70,12 +72,28 @@ def start(branch_name: BranchName, members: str = None, reset_members: bool = Fa
 
     session_settings = di.get(StartMobbing).start(branch_name, members)
 
-    click.secho(f'Driver: {session_settings.team.driver}', fg='bright_green')
-    click.secho(f'Navigator: {session_settings.team.navigator}', fg='bright_green')
+    echo(f'Driver: {session_settings.team.driver}', fg='bright_green')
+    echo(f'Navigator: {session_settings.team.navigator}', fg='bright_green')
 
     di.get(TimerService).start(session_settings.rotation.driverInMinutes)
 
-    app_name = di.get(DotEnv).APP_CLI_NAME
-    click.secho(f'Your driver round is over. Now you should run `{app_name} next`.', fg='bright_blue')
+    echo(f'Your driver round is over. Now you should run `mobt next`.', fg='bright_blue')
 
+    def _make_laptop_speak(text: str):
+        import platform
+        if platform.system() == 'Darwin':
+            subprocess.call(['say', text])
+        elif platform.system() == 'Linux':
+            subprocess.call(['espeak', text])
+        else:
+            print("\a")
+
+    import asyncio
+    async def async_functions():
+        loop = asyncio.get_running_loop()
+        await asyncio.gather(
+            loop.run_in_executor(None, lambda: _make_laptop_speak("Mob Rotate!")),
+        )
+
+    asyncio.run(async_functions())
     di.get(GuiService).show_message("Time's up!")
